@@ -16,6 +16,8 @@ import base64
 import hashlib
 import time
 
+from test_utils.retry import RetryResult
+
 
 BUCKET_NAME = u"grpm-systest-{}".format(int(1000 * time.time()))
 BUCKET_POST_URL = u"https://www.googleapis.com/storage/v1/b/"
@@ -44,6 +46,20 @@ ENCRYPTION_KEY = (
 )
 
 
+_RETRYABLE_CODES = [
+    409,  # Conflict
+    429,  # TooManyRequests
+    503,  # ServiceUnavailable
+]
+
+
+def _not_retryable(response):
+    return response.status_code not in _RETRYABLE_CODES
+
+
+retry_transient_errors = RetryResult(_not_retryable)
+
+
 def get_encryption_headers(key=ENCRYPTION_KEY):
     """Builds customer-supplied encryption key headers
 
